@@ -13,5 +13,5 @@ my $circstatus = $aleph->circ_status(sys_no => '001484478',library => 'rug01');
 if($circstatus->is_success){
   print Dumper($circstatus);
 }else{
-  say STDERR $circstatus->error;
+  say STDERR join('',@{$circstatus->errors});
 } 
