@@ -12,5 +12,5 @@ my $result = $aleph->ill_get_doc_short(doc_number => "000030527",library=>"rug01
 if($result->is_success){
   print Dumper($result->z13);
 }else{
-  say STDERR $result->error;
+  say STDERR join('',@{$result->errors});
 } 
